@@ -12,7 +12,7 @@ use File::Find;
 use File::Path qw();
 use File::ShareDir;
 use File::Temp qw(tempdir tempfile);
-use Digest::file qw(digest_file_hex);
+use Digest::SHA qw(sha1_hex);
 use Archive::Extract;
 use Config;
 use Text::Patch;
@@ -84,6 +84,16 @@ sub ACTION_code {
           $self->apply_patch("$build_src/cd", $_)  foreach (@{$self->notes('cd_patches')});
         }
       }
+      
+      ### XXX hack for handling github tarballs
+      unless (-d "$build_src/cd" && -d "$build_src/im" && -d "$build_src/iup") {
+        for my $f (glob("$build_src/*")) {
+          if ($f =~ m!^\Q$build_src\E/.*?(im|cd|iup).*$!) {
+	    print "renaming: $f $build_src/$1\n";	   
+	    rename ($f, "$build_src/$1");
+	  }
+        }
+      }
 
       my $m = $self->notes('build_debug_info') ? $self->prompt("\nDo you want to see all messages during 'make' (y/n)?", 'n') : 'n';
       $self->notes('build_msgs', lc($m) eq 'y' ? 1 : 0);
@@ -151,7 +161,6 @@ sub fetch_file {
   # check existing file
   if (-f $localfile) {
     if ($sha1) {
-      warn "Checking checksum for existing '$localfile'...\n";
       if ($self->check_sha1sum($localfile, $sha1)) {
 	return rel2abs($localfile);
       }
@@ -170,22 +179,28 @@ sub fetch_file {
   
   # checksum
   if ($sha1) {
-    warn "Checking checksum for '$localfile'...\n";
     die "###ERROR### fetch_file: checksum failed" unless $self->check_sha1sum($localfile, $sha1);
   }
   
   return rel2abs($localfile);
 }
 
-
 sub check_sha1sum {
   my ($self, $file, $sha1sum) = @_;
-  my $file_sha1sum = digest_file_hex($file, 'SHA1');
-  return 1 if $file_sha1sum eq $sha1sum;
+  return 1 if $sha1sum eq 'DO_NOT_CHECK_SHA1';
+  warn "Checking checksum for '$file'...\n";
+  my $sha1 = Digest::SHA->new;
+  my $fh;
+  open($fh, $file) or die "###ERROR## Cannot check checksum for '$file'\n";
+  binmode($fh);
+  $sha1->addfile($fh);
+  close($fh);
+  my $file_sha1sum = $sha1->hexdigest;
+  my $rv = ($file_sha1sum eq $sha1sum) ? 1 : 0;
   warn "###WARN## sha1 mismatch: got      '", $file_sha1sum , "'\n",
        "###WARN## sha1 mismatch: expected '", $sha1sum, "'\n",
-       "###WARN## sha1 mismatch: filesize ", (-s $file);
-  return 0;
+       "###WARN## sha1 mismatch: filesize ", (-s $file) unless $rv;
+  return $rv;
 }
 
 sub build_binaries {
